Crate adb_server_tokio

source ·
This is a library for interacting with the ADB server using Tokio.

Examples

Checkout the AdbServerProxy implementation in the proxy module for an example of how to use this library.

Features

  • Parse and Serailize ADB Packets
  • Proxy ADB Server Connections

References

Structs

Enums

Type Aliases

  • Result type for AdbServer errors.