Crate adb_server_tokio
source ·Expand description
This is a library for interacting with the ADB server using Tokio.
Examples
Checkout the AdbServerProxy implementation in the proxy module for an example of how to use this library.
Features
- Parse and Serailize ADB Packets
- Proxy ADB Server Connections
References
Structs
- ADB protocol header.
- ADB packet.
- ADB server codec
- Adb Server Protocol Connection
- a proxy which connects 2 adb server protocol connections and optionally logs the messages
Enums
- AdbServer error type.
Type Aliases
- Result type for AdbServer errors.